*株式会社ライトストーン
*Stata分析機能例題集　構造方程式モデリング（SEM）


*****例1 Single-facter measurementモデル*****

*サンプルデータをダウンロードし、データを確認
use https://www.stata-press.com/data/r16/sem_1fmm
summarize
notes

*フィット実行
sem(x1 x2 x3 x4 <- X)


***同じモデルをgsemにフィットさせる**

*フィット実行
gsem(x1 x2 x3 x4 <- X)


***Builderを使ってフィットさせる***

*サンプルデータをダウンロード
use https://www.stata-press.com/data/r16/sem_1fmm

*Builderに構築されたダイアグラムを呼び出す
webgetsem sem_1fmm


*****例2 published covariancesからデータセットを作成する*****

***SSDの作成***
clear all
ssd init a1 a2 a3 a4 a5 c1 c2 c3 c4 c5
ssd set obs 216
#delimit ;
ssd set cov 2038.035 /
 1631.766 1932.163 /
 1393.567 1336.871 1313.809 /
 1657.299 1647.164 1273.261 2034.216 /
 1721.830 1688.292 1498.401 1677.767 2061.875 /
 659.795 702.969 585.019 656.527 775.118 630.518 /
 779.519 790.448 653.734 764.755 871.211 500.128 741.767 /
 899.912 879.179 750.037 897.441 1008.287 648.935 679.970
 1087.409 /
 775.235 739.157 659.867 751.860 895.616 550.476 603.950
 677.865 855.272 /
 821.170 785.419 669.951 802.825 877.681 491.042 574.775
 686.391 622.830 728.674 ;
#delimit cr

*データを保存
save sem2fmm

*他に設定しなければならない項目があるかどうかを調べる
ssd status


***SSDのラベリング***

*データを確認
ssd describe

*データセットにラベルとノートを書き加える
label data "Affective and cognitive arousal"
label var a1 "affective arousal 1"
label var a2 "affective arousal 2"
label var a3 "affective arousal 3"
label var a4 "affective arousal 4"
label var a5 "affective arousal 5"
label var c1 "cognitive arousal 1"
label var c2 "cognitive arousal 2"
label var c3 "cognitive arousal 3"
label var c4 "cognitive arousal 4"
label var c5 "cognitive arousal 5"
#delimit ;
notes: Summary statistics data containing published covariances
 from Thomas OWilliams, Ronald CEaves, and Cynthia Cox,
 2 Apr 2002, "Confirmatory factor analysis of an instrument
 designed to measure affective and cognitive arousal",
 _Educational and Psychological Measurement_,
 vol62 no2, 264-283;
notes: a1-a5 report scores from 5 miniscales designed to measure
 affective arousal;
notes: c1-c5 report scores from 5 miniscales designed to measure
 cognitive arousal;
notes: The series of tests, known as the VST II
 (Visual Similes Test II) were administered to 216 children
 ages 10 to 12The miniscales are sums of scores of
 5 to 6 items in VST II;
#delimit cr
ssd describe
save sem2fmm, replace


***SSDのリスト***

*SSDのリストを作成
ssd list


*****例3 2因子のmeasurment model*****

*データの入手
use https://www.stata-press.com/data/r16/sem_2fmm

*データの内容を確認
ssd describe
notes

*フィット実行
sem(Affective -> a1 a2 a3 a4 a5)(Cognitive -> c1 c2 c3 c4 c5)

*パス係数ではなく、標準化されたパスの値を表示
sem, standardized


***Builderを使ってフィットさせる***

*サンプルデータをダウンロード
use https://www.stata-press.com/data/r16/sem_2fmm

*Builderに構築されたダイアグラムを呼び出す
webgetsem sem_2fmm


***推定式のフィットの良さを評価する***

*推定式のフィットの良さを計算
estat eqgof


*****例4 適合度（goodness-of-fit）の統計*****

*データの取得とフィット実行
use https://www.stata-press.com/data/r16/sem_2fmm
sem(Affective -> a1 a2 a3 a4 a5)(Cognitive -> c1 c2 c3 c4 c5)

*適合度を調べる
estat gof, stats(all)
